BASE = u'@base'
CONTAINER = u'@container'
CONTEXT = u'@context'
GRAPH = u'@graph'
ID = u'@id'
INDEX = u'@index'
LANG = u'@language'
LIST = u'@list'
REV = u'@reverse'
SET = u'@set'
TYPE = u'@type'
VALUE = u'@value'
VOCAB = u'@vocab'
